==============
Super Collator
==============

Collates textual sources with relaxed spelling.  Uses Gotoh's variant of the
Needleman-Wunsch sequence alignment algorithm.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   examples
   aligner
   ngrams
   references


Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
